@@ -32,6 +32,7 @@ imports.gi.versions.Tracker = '0.16';
 imports.gi.versions.TrackerMiner = '0.16';
 imports.gi.versions.EvinceDocument = '3.0';
 imports.gi.versions.Goa = '1.0';
+imports.gi.versions.WebKit = '3.0';
 
 const EvDoc = imports.gi.EvinceDocument;
 const GdPrivate = imports.gi.GdPrivate;
@@ -131,10 +132,10 @@ const Application = new Lang.Class({
                         let info = object.query_info_finish(res);
                         this.gettingStartedLocation = file.get_parent();
 
-                        GdPrivate.tracker_miner_manager_index_file_async(manager, file,
+                        manager.index_file_async(file, null,
                             function(object, res) {
                                 try {
-                                    GdPrivate.tracker_miner_manager_index_file_finish(object, res);
+                                    manager.index_file_finish(res);
                                 } catch (e) {
                                     log('Error indexing the getting started PDF: ' + e.message);
                                 }
@@ -422,8 +423,7 @@ const Application = new Lang.Class({
               window_mode: WindowMode.WindowMode.PREVIEW,
               callback: this._onActionToggle,
               state: GLib.Variant.new('b', false),
-              accel: 'F5'
-            },
+              accel: 'F5' },
             { name: 'print-current', accel: '<Primary>p',
               callback: this._onActionPrintCurrent,
               window_mode: WindowMode.WindowMode.PREVIEW },
@@ -459,6 +459,9 @@ const Application = new Lang.Class({
               window_mode: WindowMode.WindowMode.PREVIEW },
             { name: 'places',
               accel: '<Primary>b',
+              window_mode: WindowMode.WindowMode.PREVIEW },
+            { name: 'copy',
+              accel: '<Primary>c',
               window_mode: WindowMode.WindowMode.PREVIEW }
         ];
 
