@@ -113,57 +113,6 @@ gd_queue_thumbnail_job_for_file_finish (GAsyncResult *res)
   return g_simple_async_result_get_op_res_gboolean (simple);
 }
 
-/* taken from eel/eel-gtk-extensions.c */
-static gboolean 
-tree_view_button_press_callback (GtkWidget *tree_view,
-				 GdkEventButton *event,
-				 gpointer data)
-{
-	GtkTreePath *path;
-	GtkTreeViewColumn *column;
-
-	if (event->button == 1 && event->type == GDK_BUTTON_PRESS) {
-		if (gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW (tree_view),
-						   event->x, event->y,
-						   &path,
-						   &column,
-						   NULL, 
-						   NULL)) {
-			gtk_tree_view_row_activated
-				(GTK_TREE_VIEW (tree_view), path, column);
-		}
-	}
-
-	return FALSE;
-}
-
-void
-gd_gtk_tree_view_set_activate_on_single_click (GtkTreeView *tree_view,
-                                               gboolean should_activate)
-{
-	guint button_press_id;
-
-	button_press_id = GPOINTER_TO_UINT 
-		(g_object_get_data (G_OBJECT (tree_view), 
-				    "gd-tree-view-activate"));
-
-	if (button_press_id && !should_activate) {
-		g_signal_handler_disconnect (tree_view, button_press_id);
-		g_object_set_data (G_OBJECT (tree_view), 
-				   "gd-tree-view-activate", 
-				   NULL);
-	} else if (!button_press_id && should_activate) {
-		button_press_id = g_signal_connect 
-			(tree_view,
-			 "button_press_event",
-			 G_CALLBACK  (tree_view_button_press_callback),
-			 NULL);
-		g_object_set_data (G_OBJECT (tree_view), 
-				   "gd-tree-view-activate", 
-				   GUINT_TO_POINTER (button_press_id));
-	}
-}
-
 const char *
 gd_filename_get_extension_offset (const char *filename)
 {
@@ -397,34 +346,6 @@ gd_create_collection_icon (gint base_size,
   return retval;
 }
 
-/**
- * gd_create_variant_from_pixbuf:
- * @pixbuf:
- *
- * Returns: (transfer full):
- */
-GVariant *
-gd_create_variant_from_pixbuf (GdkPixbuf *pixbuf)
-{
-  GVariant *variant;
-  guchar *data;
-  guint   length;
-
-  data = gdk_pixbuf_get_pixels_with_length (pixbuf, &length);
-  variant = g_variant_new ("(iiibii@ay)",
-                           gdk_pixbuf_get_width (pixbuf),
-                           gdk_pixbuf_get_height (pixbuf),
-                           gdk_pixbuf_get_rowstride (pixbuf),
-                           gdk_pixbuf_get_has_alpha (pixbuf),
-                           gdk_pixbuf_get_bits_per_sample (pixbuf),
-                           gdk_pixbuf_get_n_channels (pixbuf),
-                           g_variant_new_from_data (G_VARIANT_TYPE_BYTESTRING,
-                                                    data, length, TRUE,
-                                                    (GDestroyNotify)g_object_unref,
-                                                    g_object_ref (pixbuf)));
-  return g_variant_ref_sink (variant);
-}
-
 void
 gd_ev_view_find_changed (EvView *view,
                          EvJobFind *job,
@@ -434,40 +355,3 @@ gd_ev_view_find_changed (EvView *view,
                         ev_job_find_get_results (job),
                         page);
 }
-
-static void
-miner_manager_index_file_thread (GTask *task,
-                                 gpointer source_object,
-                                 gpointer task_data,
-                                 GCancellable *cancellable)
-{
-  TrackerMinerManager *manager = source_object;
-  GFile *file = task_data;
-  GError *error = NULL;
-
-  tracker_miner_manager_index_file (manager, file, &error);
-  if (error != NULL)
-    g_task_return_error (task, error);
-  else
-    g_task_return_boolean (task, TRUE);
-}
-
-void
-gd_tracker_miner_manager_index_file_async (TrackerMinerManager *manager,
-                                           GFile *file,
-                                           GAsyncReadyCallback callback,
-                                           gpointer user_data)
-{
-  GTask *task = g_task_new (manager, NULL, callback, user_data);
-  g_task_set_task_data (task, g_object_ref (file), (GDestroyNotify) g_object_unref);
-  g_task_run_in_thread (task, miner_manager_index_file_thread);
-  g_object_unref (task);
-}
-
-gboolean
-gd_tracker_miner_manager_index_file_finish (TrackerMinerManager *manager,
-                                            GAsyncResult *result,
-                                            GError **error)
-{
-  return g_task_propagate_boolean (G_TASK (result), error);
-}
