@@ -35,20 +35,17 @@ const Manager = imports.manager;
 const Tweener = imports.tweener.tweener;
 const Utils = imports.utils;
 
-const _SEARCH_ENTRY_TIMEOUT = 200;
-
 const Searchbar = new Lang.Class({
     Name: 'Searchbar',
 
     _init: function() {
-        this._searchEntryTimeout = 0;
         this._searchTypeId = 0;
         this._searchMatchId = 0;
         this.searchChangeBlocked = false;
 
         this._in = false;
 
-        this.widget = new Gd.Revealer();
+        this.widget = new Gtk.Revealer();
 
         let toolbar = new Gtk.Toolbar();
         toolbar.get_style_context().add_class(Gtk.STYLE_CLASS_PRIMARY_TOOLBAR);
@@ -77,19 +74,10 @@ const Searchbar = new Lang.Class({
 
         this._searchEntry.connect('changed', Lang.bind(this,
             function() {
-                if (this._searchEntryTimeout != 0) {
-                    Mainloop.source_remove(this._searchEntryTimeout);
-                    this._searchEntryTimeout = 0;
-                }
-
                 if (this.searchChangeBlocked)
                     return;
 
-                this._searchEntryTimeout = Mainloop.timeout_add(_SEARCH_ENTRY_TIMEOUT, Lang.bind(this,
-                    function() {
-                        this._searchEntryTimeout = 0;
-                        this.entryChanged();
-                    }));
+                this.entryChanged();
             }));
 
         // connect to the search action state for visibility
@@ -236,8 +224,8 @@ const Dropdown = new Lang.Class({
                                     opacity: 0.9 });
         frame.get_style_context().add_class('documents-dropdown');
 
-        this.widget = new Gd.Revealer({ halign: Gtk.Align.CENTER,
-                                        valign: Gtk.Align.START });
+        this.widget = new Gtk.Revealer({ halign: Gtk.Align.CENTER,
+                                         valign: Gtk.Align.START });
         this.widget.add(frame);
 
         this._grid = new Gtk.Grid({ orientation: Gtk.Orientation.HORIZONTAL });
